<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Name <nam@example.com>
 * @author Foysol <ragebot1125@gmail.com>
 * @author ninetailz <ninetailz1125@gmail.com>
 * @author Khan M. B. Asad <muhammad2017@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'এই পৃষ্ঠা সম্পাদনা করুন';
$lang['btn_source']            = 'দেখান পাতা উৎস';
$lang['btn_show']              = 'দেখান পৃষ্ঠা';
$lang['btn_create']            = 'এই পৃষ্ঠা তৈরি করুন';
$lang['btn_search']            = 'অনুসন্ধান';
$lang['btn_save']              = 'সংরক্ষণ';
$lang['btn_preview']           = 'পূর্বরূপ';
$lang['btn_top']               = 'উপরে ফিরে যান ';
$lang['btn_newer']             = '<< আরো সাম্প্রতিক';
$lang['btn_older']             = 'কম সাম্প্রতিক >>';
$lang['btn_revs']              = 'প্রাচীন সংশোধন';
$lang['btn_recent']            = 'সাধিত পরিবর্তনসমূহ';
$lang['btn_upload']            = 'আপলোড করুন';
$lang['btn_cancel']            = 'বাতিল করা';
$lang['btn_index']             = 'সাইট ম্যাপ';
$lang['btn_secedit']           = 'সম্পাদন করা';
$lang['btn_login']             = 'লগইন';
$lang['btn_logout']            = 'লগ আউট';
$lang['btn_admin']             = 'অ্যাডমিন';
$lang['btn_update']            = 'আধুনিক করা';
$lang['btn_delete']            = 'মুছে ফেলা';
$lang['btn_back']              = 'পিছনে';
$lang['btn_backlink']          = 'ব্যাকলিঙ্কগুলি';
$lang['btn_subscribe']         = 'সাবস্ক্রিপশন পরিচালনা করুন';
$lang['btn_profile']           = 'প্রোফাইল আপডেট করুন';
$lang['btn_reset']             = 'রিসেট করুন';
$lang['btn_resendpwd']         = 'সেট করুন নতুন পাসওয়ার্ড';
$lang['btn_draft']             = 'সম্পাদনা খসড়া';
$lang['btn_recover']           = 'খসড়া উদ্ধার';
$lang['btn_draftdel']          = 'খসড়া মুছে দিন';
$lang['btn_revert']            = 'পুনরূদ্ধার করা';
$lang['btn_register']          = 'খাতা';
$lang['btn_apply']             = 'প্রয়োগ করা';
$lang['btn_media']             = 'মিডিয়া ম্যানেজার';
$lang['btn_deleteuser']        = 'আমার অ্যাকাউন্ট অপসারণ করুন';
$lang['btn_img_backto']        = 'ফিরে যান %s';
$lang['btn_mediaManager']      = 'মিডিয়া ম্যানেজারে দেখুন';
$lang['loggedinas']            = 'লগ ইন:';
$lang['user']                  = 'ইউজারনেম';
$lang['pass']                  = 'পাসওয়ার্ড';
$lang['newpass']               = 'নতুন পাসওয়ার্ড';
$lang['oldpass']               = 'বর্তমান পাসওয়ার্ড নিশ্চিত করুন';
$lang['passchk']               = 'আরো একবার';
$lang['remember']              = 'আমাকে মনে রেখো';
$lang['fullname']              = 'আমাকে মনে রেখো';
$lang['email']                 = 'ই মেইল';
$lang['profile']               = 'ব্যবহারকারী প্রোফাইল';
$lang['badlogin']              = 'দুঃখিত, ব্যবহারকারীর নাম বা পাসওয়ার্ড ভুল ছিল.';
$lang['badpassconfirm']        = 'দুঃখিত, পাসওয়ার্ড ভুল ছিল';
$lang['minoredit']             = 'ক্ষুদ্র পরিবর্তনসমূহ';
$lang['draftdate']             = 'খসড়া উপর স্বতঃসংরক্ষণ';
$lang['nosecedit']             = 'পাতা ইতিমধ্যে পরিবর্তিত হয়েছিল, অধ্যায় তথ্যের পরিবর্তে পুরো পাতা লোড তারিখ সীমার বাইরে ছিল.
';
$lang['search_fullresults']    = 'পূর্ণলেখা ফলাফল';
$lang['js']['willexpire']      = 'এই পৃষ্ঠার সম্পাদনার জন্য আপনার লক এক মিনিটের মধ্যে মেয়াদ শেষ সম্পর্কে. \ দ্বন্দ্ব লক টাইমার রিসেট প্রিভিউ বাটন ব্যবহার এড়াতে.';
$lang['js']['notsavedyet']     = 'অসংরক্ষিত পরিবর্তন হারিয়ে যাবে.';
$lang['js']['searchmedia']     = 'ফাইলের জন্য অনুসন্ধান';
$lang['js']['keepopen']        = 'নির্বাচনের উপর উইন্ডো খোলা রাখুন';
$lang['js']['hidedetails']     = 'বিশদ আড়াল করুন';
$lang['js']['mediatitle']      = 'লিংক সেটিংস';
$lang['js']['mediadisplay']    = 'লিংক টাইপ';
$lang['js']['mediaalign']      = 'শ্রেণীবিন্যাস';
$lang['js']['mediasize']       = 'চিত্র আকার';
$lang['js']['mediatarget']     = 'লিংক টার্গেট';
$lang['js']['mediaclose']      = 'বন্ধ করা';
$lang['js']['mediainsert']     = 'ঢোকান';
$lang['js']['mediadisplayimg'] = 'ছবিটি দেখান';
$lang['js']['mediadisplaylnk'] = 'শুধুমাত্র লিঙ্ক দেখান';
$lang['js']['mediasmall']      = 'ক্ষুদ্র সংস্করণ';
$lang['js']['mediamedium']     = 'মাধ্যম সংস্করণ';
$lang['js']['medialarge']      = 'বড় সংস্করণ';
$lang['js']['mediaoriginal']   = 'আসল সংস্করণ';
$lang['js']['medialnk']        = 'বিস্তারিত পৃষ্ঠায় লিংক';
$lang['js']['mediadirect']     = 'মূল সরাসরি লিঙ্ক';
$lang['js']['medianolnk']      = 'কোনো লিঙ্ক নাই';
$lang['js']['medianolink']     = 'ইমেজ লিঙ্ক কোরো না';
$lang['js']['medialeft']       = 'বাম দিকে ইমেজ সারিবদ্ধ কর';
$lang['js']['mediaright']      = 'ডান দিকে ইমেজ সারিবদ্ধ কর';
$lang['js']['mediacenter']     = 'মাঝখানে ইমেজ সারিবদ্ধ কর';
$lang['js']['medianoalign']    = 'কোনো সারিবদ্ধ করা প্রয়োজন নেই';
$lang['js']['nosmblinks']      = 'উইন্ডোস শেয়ার এর সাথে সংযোগ সাধন কেবল মাইক্রোসফ্ট ইন্টারনেট এক্সপ্লোরারেই সম্ভব।\nতবে আপনি লিংকটি কপি পেস্ট করতেই পারেন।';
$lang['js']['linkwiz']         = 'লিংক উইজার্ড';
$lang['js']['linkto']          = 'সংযোগের লক্ষ্য:';
$lang['js']['del_confirm']     = 'নির্বাচিত আইটেম(গুলো) আসলেই মুছে ফেলতে চান?';
$lang['js']['restore_confirm'] = 'এই সংস্করণ সত্যিই পূর্বাবস্থায় ফিরিয়ে আনতে চান?';
$lang['js']['media_diff']      = 'পার্থক্যগুলো দেখুন:';
$lang['js']['media_diff_both'] = 'পাশাপাশি';
$lang['js']['media_diff_opacity'] = 'শাইন-থ্রু';
$lang['js']['media_diff_portions'] = 'ঝেঁটিয়ে বিদায়';
$lang['js']['media_select']    = 'ফাইল নির্বাচন...';
$lang['js']['media_upload_btn'] = 'আপলোড';
$lang['js']['media_done_btn']  = 'সাধিত';
$lang['js']['media_drop']      = 'আপলোডের জন্য এখানে ফাইল ফেলুন';
$lang['js']['media_cancel']    = 'অপসারণ';
$lang['js']['media_overwrt']   = 'বর্তমান ফাইল ওভাররাইট করুন';
$lang['regmissing']            = 'দুঃখিত, আপনি সমস্ত ক্ষেত্রগুলি পূরণ করা আবশ্যক.';
$lang['reguexists']            = 'দুঃখিত, এই লগইন সঙ্গে একটি ব্যবহারকারী ইতিমধ্যেই বিদ্যমান.';
$lang['regsuccess']            = 'ব্যবহারকারী তৈরি করা হয়েছে এবং পাসওয়ার্ড ইমেইল করে পাঠানো হয়েছিল.';
$lang['regsuccess2']           = 'ব্যবহারকারী তৈরি করা হয়েছে.';
$lang['regmailfail']           = 'একটি ত্রুটি পাসওয়ার্ড মেইল পাঠানোর নেভিগেশন ছিল মনে হচ্ছে. অ্যাডমিন যোগাযোগ করুন!';
$lang['regbadmail']            = 'প্রদত্ত ইমেইল ঠিকানা সঠিক মনে হচ্ছে - আপনি এই একটি ত্রুটি মনে হলে, অ্যাডমিন যোগাযোগ';
$lang['regbadpass']            = 'দুটি প্রদত্ত পাসওয়ার্ড অভিন্ন নয়, আবার চেষ্টা করুন.';
$lang['regpwmail']             = 'আপনার DokuWiki পাসওয়ার্ড';
$lang['reghere']               = 'যদিও তোমার কোনো একাউন্ট নেই? শুধু একটি পেতে';
$lang['profna']                = 'এই উইকি প্রোফাইল পরিবর্তন সমর্থন করে না';
$lang['profnochange']          = 'এমন কোন পরিবর্তন, না কিছুই.';
$lang['profnoempty']           = 'একটি খালি নাম অথবা ইমেইল ঠিকানা অনুমোদিত নয়.';
$lang['profchanged']           = 'ইউজার প্রোফাইল সফলভাবে আপডেট.';
$lang['profnodelete']          = 'এই উইকি ব্যবহারকারী মুছে ফেলার সমর্থন করে না';
$lang['profdeleteuser']        = 'একাউন্ট মুছে দিন';
$lang['profdeleted']           = 'আপনার অ্যাকাউন্টটি এই উইকি থেকে মুছে ফেলা হয়েছে';
$lang['profconfdelete']        = 'আমি এই উইকি থেকে আমার অ্যাকাউন্ট অপসারণ করতে ইচ্ছুক. <br/> এই ক্রিয়াটি পূর্বাবস্থায় ফেরানো যায় না.';
$lang['profconfdeletemissing'] = 'নিশ্চিতকরণ চেক বক্স ticked না';
$lang['pwdforget']             = 'আপনার পাসওয়ার্ড ভুলে গেছেন? একটি নতুন পান';
$lang['resendna']              = 'এই উইকি পাসওয়ার্ড পুনরায় প্রেরণ সমর্থন করে না.';
$lang['resendpwd']             = 'জন্য সেট করুন নতুন পাসওয়ার্ড';
$lang['resendpwdmissing']      = 'দুঃখিত, আপনি সমস্ত ক্ষেত্রগুলি পূরণ করা আবশ্যক.';
$lang['resendpwdnouser']       = 'দুঃখিত, আমরা আমাদের ডাটাবেসের মধ্যে ব্যবহারকারীর খুঁজে পাচ্ছি না.';
$lang['resendpwdbadauth']      = 'দুঃখিত, এই auth কোড বৈধ নয়. আপনি সম্পূর্ণ কনফার্মেশন লিঙ্ক ব্যবহার নিশ্চিত করুন.';
$lang['resendpwdconfirm']      = 'একটি নিশ্চায়ন লিঙ্ক ইমেলের মাধ্যমে পাঠানো হয়েছে.';
$lang['resendpwdsuccess']      = 'আপনার নতুন পাসওয়ার্ড ইমেইলের মাধ্যমে পাঠানো হয়েছে.';
$lang['license']               = 'অন্যথায় নোট যেখানে ছাড়া, এই উইকি নেভিগেশন কন্টেন্ট নিম্নলিখিত লাইসেন্সের আওতায় লাইসেন্সকৃত:';
$lang['licenseok']             = 'দ্রষ্টব্য: আপনি নিম্নলিখিত লাইসেন্সের অধীনে আপনার বিষয়বস্তু লাইসেন্স সম্মত হন এই পৃষ্ঠার সম্পাদনার দ্বারা:';
$lang['searchmedia']           = 'অনুসন্ধান ফাইলের নাম:';
$lang['searchmedia_in']        = 'অনুসন্ধান %s -এ';
$lang['txt_upload']            = 'আপলোড করার জন্য নির্বাচন করুন ফাইল:';
$lang['txt_filename']          = 'হিসাবে আপলোড করুন (ঐচ্ছিক):';
$lang['txt_overwrt']           = 'বিদ্যমান ফাইল মুছে যাবে';
$lang['maxuploadsize']         = 'সর্বোচ্চ আপলোড করুন. %s-ফাইলের প্রতি.';
$lang['lockedby']              = 'বর্তমানে দ্বারা লক:';
$lang['lockexpire']            = 'তালা এ মেয়াদ শেষ:';
$lang['rssfailed']             = 'ফিডটি জোগাড় করতে গিয়ে একটি ত্রুটি ঘটেছে:';
$lang['nothingfound']          = 'কিছু পাওয়া যায়নি।';
$lang['mediaselect']           = 'মিডিয়া ফাইল';
$lang['uploadsucc']            = 'আপলোড সফল';
$lang['uploadfail']            = 'আপলোড ব্যর্থ। অনুমতি জনিত ত্রুটি কী?';
$lang['uploadwrong']           = 'আপলোড প্রত্যাখ্যাত। এই ফাইল এক্সটেনশন অননুমোদিত।';
$lang['uploadexist']           = 'ফাইল ইতিমধ্যেই বিরাজমান। কিছু করা হয়নি।';
$lang['uploadbadcontent']      = 'আপলোডকৃত সামগ্রী %s ফাইল এক্সটেনশন এর সাথে মিলেনি।';
$lang['uploadspam']            = 'স্প্যাম ব্ল্যাকলিস্ট আপলোড আটকে দিয়েছে।';
$lang['uploadxss']             = 'সামগ্রীটি ক্ষতিকর ভেবে আপলোড আটকে দেয়া হয়েছে।';
$lang['uploadsize']            = 'আপলোডকৃত ফাইলটি বেশি বড়ো। (সর্বোচ্চ %s)';
$lang['deletesucc']            = '"%s" ফাইলটি মুছে ফেলা হয়েছে।';
$lang['deletefail']            = '"%s" ডিলিট করা যায়নি - অনুমতি আছে কি না দেখুন।';
$lang['mediainuse']            = '"%s" ফাইলটি মোছা হয়নি - এটি এখনো ব্যবহৃত হচ্ছে।';
$lang['namespaces']            = 'নামস্থান';
$lang['mediafiles']            = 'ফাইল পাওয়া যাবে ';
$lang['accessdenied']          = 'আপনি এই পৃষ্ঠাটি দেখতে অনুমতি দেওয়া হয়নি';
$lang['mediausage']            = 'এই ফাইলের উল্লেখ নিম্নলিখিত সিনট্যাক্স ব্যবহার করুন:';
$lang['mediaview']             = 'মূল ফাইলটি দেখুন';
$lang['mediaroot']             = 'মূল';
$lang['mediaupload']           = 'এখানে বর্তমান নামস্থান একটি ফাইল আপলোড করুন. , Subnamespaces তৈরি আপনি ফাইল নির্বাচন পরে কোলন দ্বারা বিভাজিত আপনার ফাইলের নাম তাদের পূর্বে লিখুন করুন. কোন ফাইল এছাড়াও ড্র্যাগ এবং ড্রপ দ্বারা নির্বাচন করা সম্ভব.';
$lang['mediaextchange']        = 'ফাইল এক্সটেনশন .%s থেকে .%s\'এ পরিবর্তন হলো !';
$lang['reference']             = 'তথ্যসূত্রের জন্য ';
$lang['ref_inuse']             = 'এই ফাইল মুছে ফেলা যাবে না কারণ এটি এখনও ব্যবহৃত হচ্ছে নিম্নলিখিত পাতা দ্বারা:';
$lang['ref_hidden']            = 'এই পাতায় কিছু রেফারেন্স পড়ার আপনার আনুমতি নেই';
$lang['hits']                  = 'সফল ';
$lang['quickhits']             = 'পৃষ্ঠা মেলে';
$lang['toc']                   = 'সূচীপত্র';
$lang['current']               = 'বর্তমান';
$lang['yours']                 = 'আপনার সংস্করণ
';
$lang['diff']                  = 'বর্তমান সংস্করণের পার্থক্য দেখান ';
$lang['diff2']                 = 'নির্বাচিত সংস্করণের মধ্যে পার্থক্য দেখান ';
$lang['diff_type']             = 'পার্থক্য দেখুন:';
$lang['diff_inline']           = 'ইনলাইন';
$lang['diff_side']             = 'পাশাপাশি';
$lang['diffprevrev']           = 'পূর্ববর্তী সংস্করণ';
$lang['diffnextrev']           = 'পরবর্তী সংস্করণ';
$lang['difflastrev']           = 'সর্বশেষ সংস্করণ';
$lang['diffbothprevrev']       = 'উভয় পক্ষের পূর্ববর্তী সংস্করণ';
$lang['diffbothnextrev']       = 'উভয় পক্ষের পরবর্তী সংস্করণ';
$lang['line']                  = 'লাইন';
$lang['breadcrumb']            = 'ট্রেস:';
$lang['youarehere']            = 'আপনি এখানে আছেন:';
$lang['lastmod']               = 'শেষ বার পরিমার্জিত';
$lang['by']                    = 'দ্বারা';
$lang['deleted']               = 'মুছে ফেলা';
$lang['created']               = 'তৈরি করা';
$lang['restored']              = 'পুরানো সংস্করণের পুনঃস্থাপন (%s)';
$lang['external_edit']         = 'বাহ্যিক সম্পাদনা';
$lang['summary']               = 'সম্পাদনা সারাংশ';
$lang['noflash']               = 'এ href="http://get.adobe.com/flashplayer"> অ্যাডোবি ফ্ল্যাশ প্লাগইন </a> এই সামগ্রী প্রদর্শন করার জন্য প্রয়োজন হয়.';
$lang['download']              = 'ডাউনলোড স্নিপেট ';
$lang['tools']                 = 'সরঞ্জামসমূহ';
$lang['user_tools']            = 'ব্যবহারকারীর সরঞ্জামসমূহ';
$lang['site_tools']            = 'সাইটের সরঞ্জামসমূহ';
$lang['page_tools']            = 'পৃষ্ঠার সরঞ্জামসমূহ';
$lang['skip_to_content']       = 'বিষয়ে এড়িয়ে যান';
$lang['sidebar']               = 'সাইডবার';
$lang['mail_newpage']          = 'পৃষ্ঠা যোগ করা হয়েছে:';
$lang['mail_changed']          = 'পৃষ্ঠা পরিবর্তন করা হয়েছে:';
$lang['mail_subscribe_list']   = 'পৃষ্ঠাগুলির নামস্থান পরিবর্তন:';
$lang['mail_new_user']         = 'নতুন ব্যবহারকারী:';
$lang['mail_upload']           = 'ফাইল আপলোড করেছেন:';
$lang['changes_type']          = 'দেখুন পরিবর্তনসমূহ';
$lang['pages_changes']         = 'পৃষ্ঠাগুলি';
$lang['media_changes']         = 'মিডিয়া ফাইলগুলি';
$lang['both_changes']          = 'পেজ এবং মিডিয়া ফাইল উভয়েই';
$lang['qb_bold']               = 'গাঢ় লেখা';
$lang['qb_italic']             = 'বাঁকা লেখা';
$lang['qb_underl']             = 'আন্ডারলাইন টেক্সট';
$lang['qb_code']               = 'মোনোস্কেপ লেখা';
$lang['qb_strike']             = 'স্ট্রাইক মাধ্যমে টেক্সট';
$lang['qb_h1']                 = 'স্তর 1 শিরোনাম';
$lang['qb_h2']                 = 'স্তর 2 শিরোনাম';
$lang['qb_h3']                 = 'স্তর 3 শিরোনাম';
$lang['qb_h4']                 = 'স্তর 4 শিরোনাম';
$lang['qb_h5']                 = 'স্তর 5 শিরোনাম';
$lang['qb_h']                  = 'শিরোনাম';
$lang['qb_hs']                 = 'নির্বাচন করুন শিরোনাম';
